@@ -9,7 +9,7 @@ from scipy.interpolate import UnivariateSpline, interp1d, InterpolatedUnivariate
 
 
 logger = logging.getLogger('aug_sfutils.mapeq')
-logger.setLevel(logging.INFO)
+#logger.setLevel(logging.INFO)
 
 
 def get_nearest_index(tim_eq, tarr):
@@ -458,7 +458,12 @@ def rho2rz(eqm, rho_in, t_in=None, coord_in='rho_pol', all_lines=False):
         zs_t = []
 
         for jfl, fl in enumerate(Flux):
-            segs = cgen.create_contour(fl)
+            verts = cgen.create_contour(fl)
+            if compare_version(matplotlib.__version__, '3.4.3') >= 0:
+                """After MPL ver 3.4.3 the return type is vertices and codes as a list. Prior it was just vertices"""
+                segs = verts[0]
+            else:
+                segs = verts
             n_segs = len(segs)
             if n_segs == 0:
                 if fl == eqm.psi0[i]:
