@@ -6,7 +6,7 @@ from aug_sfutils import sfdics, str_byt
 n_rel = 8
 
 logger = logging.getLogger('aug_sfutils.sfhread')
-logger.setLevel(logging.INFO)
+#logger.setLevel(logging.INFO)
 #logger.setLevel(logging.DEBUG)
 
 
