@@ -8,7 +8,7 @@ PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
 logger = logging.getLogger('aug_sfutils.sfread')
 date_fmt = '%Y-%m-%d'
-logger.setLevel(logging.INFO)
+#logger.setLevel(logging.INFO)
 #logger.setLevel(logging.DEBUG)
 
 
@@ -58,11 +58,11 @@ def getgc(nshot=30136):
     nshot = np.max(ygc_sf[ygc_sf <= nshot])
     ygc = SFREAD(nshot, 'YGC')
     if ygc is not None:
-        rrgc     = ygc.getobject('RrGC')
-        zzgc     = ygc.getobject('zzGC')
-        inxlen   = ygc.getobject('inxlen')
-        flag_use = ygc.getobject('ixplin')
-        gcnames  = ygc.getobject('chGCnm')
+        rrgc     = ygc.getobject('RrGC', cal=False)
+        zzgc     = ygc.getobject('zzGC', cal=False)
+        inxlen   = ygc.getobject('inxlen', cal=False)
+        flag_use = ygc.getobject('ixplin', cal=False)
+        gcnames  = ygc.getobject('chGCnm', cal=False)
 
     comp_d = {}
 
@@ -259,7 +259,7 @@ class SFREAD:
         return None
 
 
-    def getobject(self, obj, cal=False, nbeg=None, nend=None, tbeg=None, tend=None):
+    def getobject(self, obj, cal=True, nbeg=None, nend=None, tbeg=None, tend=None):
         """
         Reads the data of a given TB, AB, SIG or SGR
         """
@@ -293,12 +293,9 @@ class SFREAD:
             if otyp == TimeBase:
                 return tb[jt_beg: jt_end]
             elif otyp in (Signal, AreaBase) or self.time_last(obj):
-                return self.getobject(obj, nbeg=jt_beg, nend=jt_end)
+                return self.getobject(obj, cal=cal, nbeg=jt_beg, nend=jt_end)
             elif self.time_first(obj):
-                return self.getobject(obj)[jt_beg: jt_end]
-#            elif otyp == AreaBase:
-#                print(self.getobject(obj).shape)
-                return self.getobject(obj)[jt_beg: jt_end]
+                return self.getobject(obj, cal=cal)[jt_beg: jt_end]
             else:
                 logger.error('Object %s: tbeg, tend keywords supported only when time is first or last dim', obj)
                 return None
